@@ -1,8 +1,7 @@
 import base64
 import binascii
 import configparser
-import inspect
-import json
+import contextlib
 import os
 import sys
 import time
@@ -17,30 +16,26 @@ import pyotp
 import requests
 from requests.adapters import HTTPAdapter
 from requests.exceptions import ConnectionError
-from requests.packages.urllib3.util.retry import Retry
 
-from apigee import (
-    APIGEE_CLI_ACCESS_TOKEN_FILE,
-    APIGEE_CLI_CREDENTIALS_FILE,
-    APIGEE_CLI_DIRECTORY,
-    APIGEE_CLI_IS_MACHINE_USER,
-    APIGEE_OAUTH_URL,
-    APIGEE_SAML_LOGIN_URL,
-    APIGEE_ZONENAME_OAUTH_URL,
-    console,
-)
+from apigee import (APIGEE_CLI_ACCESS_TOKEN_FILE, APIGEE_CLI_CREDENTIALS_FILE,
+                    APIGEE_CLI_DIRECTORY, APIGEE_CLI_IS_MACHINE_USER,
+                    APIGEE_OAUTH_URL, APIGEE_SAML_LOGIN_URL,
+                    APIGEE_ZONENAME_OAUTH_URL, console)
 from apigee.cls import AliasedGroup
-
 # from apigee.prefix import common_prefix_options
 from apigee.silent import common_silent_options
 from apigee.types import Struct
 from apigee.utils import make_dirs
 from apigee.verbose import common_verbose_options
 
+# from requests.packages.urllib3.util.retry import Retry
+
+
+
 
 def attach_username_option(func, profile):
     username = get_credential(profile, "username")
-    username_envvar = os.environ.get(f"APIGEE_USERNAME", "")
+    username_envvar = os.environ.get("APIGEE_USERNAME", "")
     if username:
         func = click.option(
             "-u", "--username", default=username, show_default="current username"
@@ -56,7 +51,7 @@ def attach_username_option(func, profile):
 
 def attach_password_option(func, profile):
     password = get_credential(profile, "password")
-    password_envvar = os.environ.get(f"APIGEE_PASSWORD", "")
+    password_envvar = os.environ.get("APIGEE_PASSWORD", "")
     if password:
         func = click.option(
             "-p", "--password", default=password, show_default="current password"
@@ -72,7 +67,7 @@ def attach_password_option(func, profile):
 
 def attach_mfa_secret_option(func, profile):
     mfa_secret = get_credential(profile, "mfa_secret")
-    mfa_envvar = os.environ.get(f"APIGEE_MFA_SECRET", "")
+    mfa_envvar = os.environ.get("APIGEE_MFA_SECRET", "")
     if mfa_secret:
         func = click.option(
             "-mfa", "--mfa-secret", default=mfa_secret, show_default="current mfa key"
@@ -88,7 +83,7 @@ def attach_mfa_secret_option(func, profile):
 
 def attach_is_token_option(func, profile):
     is_token = get_credential(profile, "is_token")
-    is_token_envvar = os.environ.get(f"APIGEE_IS_TOKEN", "")
+    is_token_envvar = os.environ.get("APIGEE_IS_TOKEN", "")
     if is_token in (True, "True", "true", "1"):
         func = click.option(
             "--token/--no-token",
@@ -137,7 +132,7 @@ def attach_zonename_option(func, profile):
 
 def attach_org_option(func, profile):
     org = get_credential(profile, "org")
-    org_envvar = os.environ.get(f"APIGEE_ORG", "")
+    org_envvar = os.environ.get("APIGEE_ORG", "")
     if org:
         func = click.option("-o", "--org", default=org, show_default="current org")(
             func
@@ -154,11 +149,9 @@ def attach_org_option(func, profile):
 def common_auth_options(func):
     profile = "default"
     for i, arg in enumerate(sys.argv):
-        if arg == "-P" or arg == "--profile":
-            try:
+        if arg in ["-P", "--profile"]:
+            with contextlib.suppress(IndexError):
                 profile = sys.argv[i + 1]
-            except IndexError:
-                pass
     attach_username_option(func, profile)
     attach_password_option(func, profile)
     attach_mfa_secret_option(func, profile)
@@ -178,12 +171,9 @@ def common_auth_options(func):
 def check_access_token(auth_obj):
     access_token = ""
     make_dirs(APIGEE_CLI_DIRECTORY)
-    try:
+    with contextlib.suppress(IOError, OSError):
         with open(APIGEE_CLI_ACCESS_TOKEN_FILE, "r") as f:
             access_token = f.read().strip()
-    except (IOError, OSError):
-        pass
-
     if access_token:
         decoded = jwt.decode(
             access_token,
@@ -287,20 +277,22 @@ def build_auth_error_message(error):
     return error_message
 
 
-def get_access_token(
-    auth, retries=4, backoff_factor=0.3, status_forcelist=(500, 502, 504), session=None
-):
+# def get_access_token(
+#     auth, retries=4, backoff_factor=0.3, status_forcelist=(500, 502, 504), session=None
+# ):
+def get_access_token(auth, session=None):
     oauth_url = APIGEE_OAUTH_URL
     username = auth.username
     password = auth.password
-    retry = Retry(
-        total=retries,
-        read=retries,
-        connect=retries,
-        backoff_factor=backoff_factor,
-        status_forcelist=status_forcelist,
-    )
-    adapter = HTTPAdapter(max_retries=retry)
+    # retry = Retry(
+    #     total=retries,
+    #     read=retries,
+    #     connect=retries,
+    #     backoff_factor=backoff_factor,
+    #     status_forcelist=status_forcelist,
+    # )
+    # adapter = HTTPAdapter(max_retries=retry)
+    adapter = HTTPAdapter()
     session = requests.Session()
     session.mount("https://", adapter)
     post_headers = {
@@ -334,11 +326,13 @@ def get_credential(section, key):
         config.read(APIGEE_CLI_CREDENTIALS_FILE)
         if section in config:
             return config[section][key]
-    except:
+    except Exception:
         return
 
 
-def set_header(auth_obj, headers={}):
+def set_header(auth_obj, headers=None):
+    if headers is None:
+        headers = {}
     if auth_obj.mfa_secret or auth_obj.token or auth_obj.zonename:
         access_token = check_access_token(auth_obj)
         if not access_token:
