@@ -1,18 +1,8 @@
-import sys
-
 import click
 
 from apigee import APIGEE_CLI_SYMMETRIC_KEY, console
 from apigee.auth import common_auth_options, gen_auth
-from apigee.crypto import (
-    ENCRYPTED_HEADER_BEGIN,
-    ENCRYPTED_HEADER_END,
-    decrypt_message,
-    encrypt_message,
-    is_encrypted,
-)
 from apigee.keyvaluemaps.keyvaluemaps import Keyvaluemaps
-from apigee.keyvaluemaps.serializer import KeyvaluemapsSerializer
 from apigee.prefix import common_prefix_options
 from apigee.silent import common_silent_options
 from apigee.utils import read_file, write_file
